<?php # $Id: serendipity_lang_nl.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Christiaan Heerze <webmaster@heimp.nl>
# http://www.heimp.nl
# (c) 2007 Sam Geeraerts <samgee@elmundolibre.be>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'nl_BE.UTF8, nl_BE.UTF-8, dutch, nl_BE, nl');
@define('DATE_FORMAT_ENTRY', '%A, %e %B %Y');
@define('DATE_FORMAT_SHORT', '%d-%m-%Y %H:%M');
@define('WYSIWYG_LANG', 'nl-utf');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Beheer');
@define('HAVE_TO_BE_LOGGED_ON', 'U moet ingelogd zijn om deze pagina te kunnen bekijken');
@define('WRONG_USERNAME_OR_PASSWORD', 'Waarschijnlijk heeft u een ongeldige gebruikersnaam of wachtwoord ingevoerd.');
@define('APPEARANCE', 'Uiterlijk');
@define('MANAGE_STYLES', 'Beheer Stijlen');
@define('CONFIGURE_PLUGINS', 'Configureer Plugins');
@define('CONFIGURATION', 'Configuratie');
@define('BACK_TO_BLOG', 'Terug naar het Weblog');
@define('LOGIN', 'Aanmelden');
@define('LOGOUT', 'Afmelden');
@define('LOGGEDOUT', 'Afgemeld.');
@define('CREATE', 'Aanmaken');
@define('EDIT_THIS_CAT', 'Bewerken "%s"');
@define('SAVE', 'Opslaan');
@define('NAME', 'Naam');
@define('CREATE_NEW_CAT', 'Maak een nieuwe categorie aan');
@define('I_WANT_THUMB', 'Ik wil de miniatuur in mijn artikel gebruiken.');
@define('I_WANT_BIG_IMAGE', 'Ik wil de grote afbeelding in mijn artikel gebruiken.');
@define('I_WANT_NO_LINK', ' Ik wil een gewone afbeelding');
@define('I_WANT_IT_TO_LINK', 'Ik wil dat de afbeelding verwijst naar de volgende pagina:');
@define('BACK', 'Terug');
@define('FORWARD', 'Verder');
@define('ANONYMOUS', 'Anoniem');
@define('NEW_TRACKBACK_TO', 'Nieuwe trackback gemaakt voor');
@define('NEW_COMMENT_TO', 'Nieuwe reactie op');
@define('RECENT', 'Recentelijk...');
@define('OLDER', 'Ouder...');
@define('DONE', 'Gedaan');
@define('WELCOME_BACK', 'Welkom terug,');
@define('TITLE', 'Onderwerp');
@define('DESCRIPTION', 'Beschrijving');
@define('PLACEMENT', 'Placement');
@define('DELETE', 'Verwijderen');
@define('UP', 'OP');
@define('DOWN', 'NEER');
@define('ENTRIES', 'artikelen');
@define('NEW_ENTRY', 'Nieuw artikel');
@define('EDIT_ENTRIES', 'Bewerk artikelen');
@define('CATEGORIES', 'Categorieën');
@define('WARNING_THIS_BLAHBLAH', "WAARSCHUWING:\\nDit kan veel tijd in beslag nemen als er veel grote afbeeldingen zijn zonder miniatuur.");
@define('CREATE_THUMBS', 'Creëer nieuwe indexafbeeldingen');
@define('MANAGE_IMAGES', 'Beheer afbeeldingen');
@define('NAME', 'Naam');
@define('EMAIL', 'E-mail');
@define('HOMEPAGE', 'Homepage');
@define('COMMENT', 'Reactie');
@define('REMEMBER_INFO', 'Informatie onthouden? ');
@define('SUBMIT_COMMENT', 'Reactie plaatsen');
@define('NO_ENTRIES_TO_PRINT', 'Er zijn geen artikelen om weer te geven');
@define('COMMENTS', 'Reacties');
@define('ADD_COMMENT', 'Reactie toevoegen');
@define('NO_COMMENTS', 'Geen reacties');
@define('POSTED_BY', 'Geplaatst door');
@define('ON', 'op');
@define('A_NEW_COMMENT_BLAHBLAH', 'Er is een nieuwe reactie geplaatst op uw weblog "%s", op het artikel getiteld "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Een nieuwe trackback is aangemaakt naar uw weblogartikel getiteld "%s".');
@define('NO_CATEGORY', 'Geen categorie');
@define('ENTRY_BODY', 'Artikeltekst');
@define('EXTENDED_BODY', 'Uitgebreide tekst');
@define('CATEGORY', 'Categorie');
@define('EDIT', 'Bewerk');
@define('NO_ENTRIES_BLAHBLAH', 'Er zijn geen artikelen gevonden voor zoekopdracht %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Uw zoekopdracht naar %s heeft %s zoekresultaten opgeleverd:');
@define('IMAGE', 'Afbeelding');
@define('ERROR_FILE_NOT_EXISTS', 'Fout: Oude bestandsnaam bestaat niet!');
@define('ERROR_FILE_EXISTS', 'Fout: Nieuwe bestandsnaam is reeds in gebruik, kies een andere!');
@define('ERROR_SOMETHING', 'Fout: Er gaat iets fout');
@define('ADDING_IMAGE', 'Afbeelding toevoegen...');
@define('THUMB_CREATED_DONE', 'Miniatuur gemaakt.<br/>Gedaan.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Fout: Bestand bestaat al!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Er is een onbekende fout opgetreden, het bestand is niet verzonden. Misschien is het bestand groter dan uw server toestaat. Controleer dit bij uw provider of bewerk uw php.ini zodat deze grotere bestanden toelaat.');
@define('GO', 'Uitvoeren!');
@define('NEWSIZE', 'Nieuwe grootte: ');
@define('RESIZE_BLAHBLAH', '<b>Vergroten/Verkleinen %s</b>');
@define('ORIGINAL_SIZE', 'Originele grootte: <i>%sx%s</i> pixels');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hier kunt u de grootte van de afbeelding aanpassen. Als u de afbeeldingsverhoudingen wilt behouden, voer dan in één van de velden een waarde in en druk op de TAB-toets -- Het programma zal dan zelf de andere grootte berekenen zodat de verhoudingen hetzelfde blijven</p>');
@define('QUICKJUMP_CALENDAR', 'Quickjump Kalender');
@define('QUICKSEARCH', 'Zoeken');
@define('SEARCH_FOR_ENTRY', 'Zoek naar een artikel');
@define('ARCHIVES', 'Archief');
@define('BROWSE_ARCHIVES', 'Blader door het archief per maand');
@define('TOP_REFERRER', 'Topverwijzers');
@define('SHOWS_TOP_SITES', 'Toont de websites die uw weblog de meeste bezoekers bezorgen.');
@define('TOP_EXITS', 'Top uitgaande hyperlinks');
@define('SHOWS_TOP_EXIT', 'Toont de populairste hyperlinks waarmee bezoekers uw weblog verlaten.');
@define('SYNDICATION', 'Verzamelpublicatie');
@define('SHOWS_RSS_BLAHBLAH', 'Toont de hyperlinks voor verzamelpublicatie');
@define('ADVERTISES_BLAHBLAH', 'Toont een link waar anderen Serendipity software kunnen downloaden');
@define('HTML_NUGGET', 'HTML-blokje');
@define('HOLDS_A_BLAHBLAH', 'Een stukje waarin u uw eigen HTML-tekst kunt schrijven, deze verschijnt aan de zijkant');
@define('TITLE_FOR_NUGGET', 'Titel van het blokje');
@define('THE_NUGGET', 'Het blokje HTML!');
@define('SYNDICATE_THIS_BLOG', 'Abonneren op dit weblog');
@define('YOU_CHOSE', 'U koos voor %s');
@define('IMAGE_ROTATE_LEFT', 'Roteer de afbeelding 90 graden tegen de klok in');
@define('IMAGE_ROTATE_RIGHT', 'Roteer de afbeelding 90 graden met de klok mee');
@define('IMAGE_SIZE', 'Grootte van de afbeelding');
@define('IMAGE_AS_A_LINK', 'Verwijzing');
@define('POWERED_BY', 'Aangedreven door');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Geen Trackbacks');
@define('TOPICS_OF', 'Onderwerpen bij');
@define('VIEW_FULL', 'bekijk volledig');
@define('VIEW_TOPICS', 'bekijk onderwerpen');
@define('AT', 'op');
@define('SET_AS_TEMPLATE', 'Gebruik als template');
@define('IN', 'in');
@define('EXCERPT', 'Uittreksel');
@define('TRACKED', 'Gevolgd');
@define('LINK_TO_ENTRY', 'Link naar artikel');
@define('LINK_TO_REMOTE_ENTRY', 'Link naar extern artikel');
@define('IP_ADDRESS', 'IP-adres');
@define('USER', 'Gebruiker');
@define('THUMBNAIL_USING_OWN', 'Geen miniatuur aangemaakt voor %s omdat het al klein genoeg is.');
@define('THUMBNAIL_FAILED_COPY', '%s kon niet gekopieerd worden en kan dus niet als miniatuur gebruikt worden!');
@define('AUTHOR', 'Auteur');
@define('LAST_UPDATED', 'Laatst bewerkt');
@define('TRACKBACK_SPECIFIC', 'Trackback-URI voor dit artikel');
@define('DIRECT_LINK', 'Directe link naar dit artikel');
@define('COMMENT_ADDED', 'Uw reactie is succesvol toegevoegd. ');
@define('COMMENT_ADDED_CLICK', 'Keer terug naar de %sreacties%s of %ssluit%s dit scherm.');
@define('COMMENT_NOT_ADDED_CLICK', 'Keer terug naar de %sreacties%s of %ssluit%s dit scherm.');
@define('COMMENTS_DISABLE', 'Sta geen reacties toe op dit artikel');
@define('COMMENTS_ENABLE', 'Sta reacties toe op dit artikel');
@define('COMMENTS_CLOSED', 'De auteur staat geen reacties toe op dit artikel');
@define('EMPTY_COMMENT', 'Uw reactie bevatte geen tekst, %sga terug%s en probeer opnieuw');
@define('ENTRIES_FOR', 'Artikelen van %s');
@define('DOCUMENT_NOT_FOUND', 'Het document %s is helaas niet gevonden.');
@define('USERNAME', 'Gebruikersnaam');
@define('PASSWORD', 'Wachtwoord');
@define('AUTOMATIC_LOGIN', 'Bewaar deze informatie');
@define('SERENDIPITY_INSTALLATION', 'Serendipity Installatie');
@define('LEFT', 'links');
@define('RIGHT', 'rechts');
@define('HIDDEN', 'verborgen');
@define('REMOVE_TICKED_PLUGINS', 'Verwijder geselecteerde plugins');
@define('SAVE_CHANGES_TO_LAYOUT', 'Bewaar veranderingen in ontwerp');
@define('COMMENTS_FROM', 'Reactie van');
@define('ERROR', 'Fout');
@define('ENTRY_SAVED', 'Uw artikel is bewaard');
@define('DELETE_SURE', 'Weet u zeker dat u artikel #%s definitief wilt verwijderen?');
@define('NOT_REALLY', 'Nee');
@define('DUMP_IT', 'Ja');
@define('RIP_ENTRY', 'Artikel #%s is verwijderd');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categorie #%s is verwijderd. Aanwezige artikelen zijn verplaatst naar categorie #%s');
@define('CATEGORY_DELETED', 'Categorie #%s is verwijderd.');
@define('INVALID_CATEGORY', 'Er is geen categorie opgegeven om te verwijderen');
@define('CATEGORY_SAVED', 'Categorie is opgeslagen');
@define('SELECT_TEMPLATE', 'Selecteer een template dat u wenst te gebruiken voor uw weblog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Artikelen zijn niet succesvol ingevoerd!');
@define('MT_DATA_FILE', 'Movable Type databestand');
@define('FORCE', 'Forceer');
@define('CREATE_AUTHOR', 'Maak auteur \'%s\' aan.');
@define('CREATE_CATEGORY', 'Maak categorie \'%s\' aan.');
@define('MYSQL_REQUIRED', 'U moet een MySQL-verbinding hebben om deze actie te voltooien.');
@define('COULDNT_CONNECT', 'Kan geen verbinding maken met de volgende MySQL-databank: %s.');
@define('COULDNT_SELECT_DB', 'Kan de volgende databank niet selecteren: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Kan de volgende gebruikersinformatie niet selecteren: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Kan de volgende categorie niet selecteren: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Kan de volgende artikelen niet selecteren: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Kan de volgende reacties niet selecteren: %s.');
@define('YES', 'Ja');
@define('NO', 'Nee');
@define('USE_DEFAULT', 'Standaard');
@define('CHECK_N_SAVE', 'Controleren &amp; bewaren');
@define('DIRECTORY_WRITE_ERROR', 'Kan niet schrijven naar map %s. Controleer de toegangsrechten.');
@define('DIRECTORY_CREATE_ERROR', 'Map %s bestaat niet en kon niet worden aangemaakt. Maak deze alstublieft handmatig aan');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; voer <i>%s %s</i> uit');
@define('CANT_EXECUTE_BINARY', 'Kan opdracht %s niet uitvoeren');
@define('FILE_WRITE_ERROR', 'Kan niet schrijven naar bestand %s.');
@define('FILE_CREATE_YOURSELF', 'Maak zelf het bestand aan of controleer de toegangsrechten');
@define('COPY_CODE_BELOW', '<br />* Kopieer de onderstaande code en voeg deze toe aan het bestand %s in de map %s:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Verander gebruiker \'www\' in de gebruiker die de apache-server draait (bijvoorbeeld nobody).');
@define('BROWSER_RELOAD', 'Herlaad daarna de pagina.');
@define('DIAGNOSTIC_ERROR', 'Serendipity heeft fouten gevonden in de door u opgegeven informatie tijdens het uitvoeren van een diagnostisch programma:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity is nog niet geïnstalleerd. <a href="%s">Installeer</a> het nu alstublieft.');
@define('INCLUDE_ERROR', 'Fout: Kan %s niet invoegen - wordt afgesloten.');
@define('DATABASE_ERROR', 'Fout: Kan geen verbinding maken met de databank - wordt afgesloten.');
@define('CREATE_DATABASE', 'Standaarddatabank aanmaken...');
@define('ATTEMPT_WRITE_FILE', 'Bestand %s proberen aan te maken...');
@define('WRITTEN_N_SAVED', 'Configuratie geschreven &amp; opgeslagen');
@define('IMAGE_ALIGNMENT', 'Uitlijning');
@define('ENTER_NEW_NAME', 'Voer een nieuwe naam in voor: ');
@define('RESIZING', 'Grootte aanpassen');
@define('RESIZE_DONE', 'Gereed (%s afbeeldingen aangepast).');
@define('SYNCING', 'Bezig met het synchroniseren van de databank met de map waar de afbeeldingen in staan');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Gereed (%s afbeeldingen gesynchroniseerd).');
@define('FILE_NOT_FOUND', 'Kan bestand <b>%s</b> niet vinden, mogelijk is deze reeds verwijderd.');
@define('ABORT_NOW', 'Annuleren');
@define('REMOTE_FILE_NOT_FOUND', 'Het bestand is niet gevonden, weet u zeker dat de URL <b>%s</b> correct is?');
@define('FILE_FETCHED', '%s opgehaald als %s');
@define('FILE_UPLOADED', 'Het bestand %s is succesvol geüpload als %s');
@define('WORD_OR', 'Of');
@define('SCALING_IMAGE', 'Grootte aanpassen van %s naar %s x %s px');
@define('KEEP_PROPORTIONS', 'Behoud verhoudingen');
@define('REALLY_SCALE_IMAGE', 'Wilt u de afbeelding echt aanpassen? Dit kan niet ongedaan gemaakt worden!');
@define('TOGGLE_ALL', 'Alles uit- of inklappen');
@define('TOGGLE_OPTION', 'Uit-/inklappen');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonneer op dit artikel');
@define('UNSUBSCRIBE_OK', 'Het abonnement op dit artikel is nu opgezegd voor %s');
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nieuwe reactie op geabonneerd artikel "%s"');
@define('SUBSCRIPTION_MAIL', "Geachte %s,\n\nEen nieuwe reactie is geplaatst op \"%s\", op artikel \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt de reactie hier vinden: %s\n\nU kunt zich uitschrijven door op deze hyperlink te klikken: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Geachte %s,\n\nEen nieuwe trackback is toegevoegd op\"%s\", op artikel \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt het artikel hier vinden: %s\n\nU kunt zich uitschrijven door op deze hyperlink te klikken: %s\n");
@define('SIGNATURE', "\n-- \n%s wordt aangedreven door Serendipity, één van de beste weblogs.\nU kunt het ook gebruiken: ga naar <http://s9y.org> om te ontdekken hoe.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91-toevoer');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0-toevoer');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0-toevoer');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0-toevoer reacties');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3-toevoer');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Veld "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Veld "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Afbeelding voor de RSS-toevoer');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Breedte van de afbeelding');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Hoogte van de afbeelding');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-mailadres van de webmaster, indien beschikbaar. (leeg: verborgen) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mailadres van de beherende redacteur, indien beschikbaar. (leeg: verborgen) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL van een afbeelding in GIF/JPEG/PNG-formaat, indien beschikbaar. (leeg: Serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'in pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'in pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Veld "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Aantal minuten waarna uw weblog niet meer gecached mag worden door externe websites/applicaties (leeg: verborgen) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Veld "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Moet het "pubDate"-veld worden geïntegreerd in uw RSS-toevoer, om zo de dag van de laatste artikel te tonen?');
@define('CONTENT', 'Inhoud');
@define('TYPE', 'Type');
@define('DRAFT', 'Concept');
@define('PUBLISH', 'Publiceren');
@define('PREVIEW', 'Voorvertoning');
@define('DATE', 'Datum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Opgelet: De door u ingevoerde datum is niet correct. Het moet opgegeven worden in het volgende formaat JJJJ-MM-DD hh:mm. Bijvoorbeeld 1970-12-31 14:39');
@define('CATEGORY_PLUGIN_DESC', 'Toont de lijst met categorieën.');
@define('ALL_AUTHORS', 'Alle auteurs');
@define('CATEGORIES_TO_FETCH', 'Op te halen categorieën');
@define('CATEGORIES_TO_FETCH_DESC', 'Categorieën op van welke auteur ophalen?');
@define('PAGE_BROWSE_ENTRIES', 'Pagina %s van %s, totaal %s artikelen');
@define('PREVIOUS_PAGE', 'vorige pagina');
@define('NEXT_PAGE', 'volgende pagina');
@define('ALL_CATEGORIES', 'Alle categorieën');
@define('DO_MARKUP', 'Voer tekstopmaakveranderingen uit');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Datumformaat');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'De echte datum van het artikel, gebruikmakend van PHPs strftime()-variabelen. (Standaard: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Kan de template niet openen, werk alstublieft Serendipity bij!');
@define('ADVANCED_OPTIONS', 'Geavanceerde Opties');
@define('EDIT_ENTRY', 'Bewerk artikel');
@define('HTACCESS_ERROR', 'Om de installatie van uw webserver te controleren moet Serendipity kunnen schrijven naar het bestand ".htaccess". Dit was helaas niet mogelijk vanwege verkeerde toegangsrechten. Pas deze alstublieft als volgt aan: <br />&nbsp;&nbsp;%s<br />en laad deze pagina opnieuw.');
@define('SIDEBAR_PLUGINS', 'Zijbalkplugins');
@define('EVENT_PLUGINS', 'Evenementenplugins');
@define('SORT_ORDER', 'Sorteervolgorde');
@define('SORT_ORDER_NAME', 'Bestandsnaam');
@define('SORT_ORDER_EXTENSION', 'Bestandsextensie');
@define('SORT_ORDER_SIZE', 'Bestandsgrootte');
@define('SORT_ORDER_WIDTH', 'Afbeeldingsbreedte');
@define('SORT_ORDER_HEIGHT', 'Afbeeldingshoogte');
@define('SORT_ORDER_DATE', 'Uploaddatum');
@define('SORT_ORDER_ASC', 'Oplopend');
@define('SORT_ORDER_DESC', 'Aflopend');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Tekstopmaak toepassen op %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Begin van de week');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity heeft ontdekt dat u uw configuratie wilt bijwerken van versie %s naar versie %s. <a href="%s">Klik hier</a> om dat proces te voltooien.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hallo en welkom bij de Serendipity bijwerkassistent.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Ik zal u helpen uw Serendipity %s-installatie bij te werken.');
@define('SERENDIPITY_UPGRADER_WHY', 'U krijgt deze melding te zien omdat u zojuist Serendipity %s geïnstalleerd heeft, maar uw databank nog niet bijgewerkt is naar deze versie');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Databankupdates (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'De volgende .sql-bestanden moeten uitgevoerd worden voordat Serendipity normaal verder kan functioneren');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Taken specifiek voor deze versie');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Geen specifieke taken gevonden voor deze versie');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Wilt u dat ik de bovenstaande taken uitvoer?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nee, ik voer ze zelf uit');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ja, graag');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'U hoeft niets bij te werken');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity is bijgewerkt');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'U heeft ervoor gekozen om niets bij te werken. Zorg ervoor dat uw databank goed geïnstalleerd is en geplande taken uitgevoerd worden');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Uw Serendipity-installatie is nu bijgewerkt naar versie %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'U kunt terugkeren naar uw weblog door %shier%s te klikken');
@define('MANAGE_USERS', 'Beheer gebruikers');
@define('CREATE_NEW_USER', 'Maak nieuwe gebruiker aan');
@define('CREATE_NOT_AUTHORIZED', 'U kunt geen gebruikers bewerken met hetzelfde gebruikersniveau als uzelf');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'U kunt geen gebruikers aanmaken met een hoger gebruikersniveau dan uzelf');
@define('CREATED_USER', '%s is aangemaakt als nieuwe gebruiker');
@define('MODIFIED_USER', 'De eigenschappen van gebruiker %s zijn gewijzigd');
@define('USER_LEVEL', 'Gebruikersniveau');
@define('DELETE_USER', 'U staat op het punt de volgende gebruiker te verwijderen: #%d %s. Weet u zeker dat u deze gebruiker wilt verwijderen? Als u dit doet zullen de artikelen van deze gebruiker niet meer worden weergegeven.');
@define('DELETED_USER', 'Gebruiker #%d %s is verwijderd.');
@define('LIMIT_TO_NUMBER', 'Hoeveel items moeten er worden weergegeven?');
@define('ENTRIES_PER_PAGE', 'artikelen per pagina');
@define('XML_IMAGE_TO_DISPLAY', 'Verzamelpublicatieafbeelding');
@define('XML_IMAGE_TO_DISPLAY_DESC','Deze afbeelding wordt getoond bij hyperlinks naar verzamelpublicaties. Laat het veld leeg voor de standaardinstellingen, voer \'none\' in om het uit te schakelen.');

@define('DIRECTORIES_AVAILABLE', 'In de lijst van beschikbare mappen kunt u een willekeurige map selecteren om een nieuwe map in aan te maken.');
@define('ALL_DIRECTORIES', 'alle mappen');
@define('MANAGE_DIRECTORIES', 'Beheer mappen');
@define('DIRECTORY_CREATED', 'Map <strong>%s</strong> is aangemaakt.');
@define('PARENT_DIRECTORY', 'Bovenliggende map');
@define('CONFIRM_DELETE_DIRECTORY', 'Weet u zeker dat u de volledige inhoud van map %s wilt verwijderen?');
@define('ERROR_NO_DIRECTORY', 'Fout: Map %s bestaat niet');
@define('CHECKING_DIRECTORY', 'Bestanden in map %s aan het controleren');
@define('DELETING_FILE', 'Bestand %s aan het verwijderen...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Kan een map die nog niet leeg is niet verwijderen. Vink "force deletion" aan als u ook deze bestanden wilt verwijderen en probeer opnieuw. Aanwezige bestanden zijn:');
@define('DIRECTORY_DELETE_FAILED', 'Het verwijderen van map %s is niet gelukt. Controleer de toegangsrechten of de bovenstaande meldingen.');
@define('DIRECTORY_DELETE_SUCCESS', 'Map %s is succesvol verwijderd.');
@define('SKIPPING_FILE_EXTENSION', 'Bestand overgeslagen: %s heeft geen extensie.');
@define('SKIPPING_FILE_UNREADABLE', 'Bestand overgeslagen: %s is niet leesbaar.');
@define('FOUND_FILE', 'Een nieuw of aangepast bestand is gevonden: %s.');
@define('ALREADY_SUBCATEGORY', '%s is reeds een subcategorie van %s.');
@define('PARENT_CATEGORY', 'Bovenliggende categorie');
@define('IN_REPLY_TO', 'Reactie op');
@define('TOP_LEVEL', 'Bovenste niveau');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s-toevoer');
@define('PERMISSIONS', 'Toegangsrechten');
@define('INTEGRITY', 'Verify Installation Integrity');
@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
@define('CHECKSUMS_PASS', 'All required files verified.');
@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
@define('SETTINGS_SAVED_AT', 'De instellingen zijn opgeslagen in %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Databankinstellingen');
@define('INSTALL_CAT_DB_DESC', 'Hier kunt u de instellingen van uw databank invoeren. Serendipity heeft deze nodig om te functioneren');
@define('INSTALL_DBTYPE', 'Databanktype');
@define('INSTALL_DBTYPE_DESC', 'Databanktype');
@define('INSTALL_DBHOST', 'Databankhost');
@define('INSTALL_DBHOST_DESC', 'De hostnaam van uw databank');
@define('INSTALL_DBUSER', 'Databankgebruiker');
@define('INSTALL_DBUSER_DESC', 'De gebruikersnaam die nodig is om verbinding te maken met uw databank');
@define('INSTALL_DBPASS', 'Databankwachtwoord');
@define('INSTALL_DBPASS_DESC', 'Het wachtwoord behorend bij de ingevoerde gebruikersnaam');
@define('INSTALL_DBNAME', 'Databanknaam');
@define('INSTALL_DBNAME_DESC', 'De naam van uw databank');
@define('INSTALL_DBPREFIX', 'Databankvoorvoegsel');
@define('INSTALL_DBPREFIX_DESC', 'Het voorvoegsel voor de tabelnamen, bijvoorbeeld serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Paden');
@define('INSTALL_CAT_PATHS_DESC', 'Diverse paden naar essentiële mappen en bestanden. Paden naar mappen moeten eindigen met een slash!');
@define('INSTALL_FULLPATH', 'Volledig pad');
@define('INSTALL_FULLPATH_DESC', 'Het volledige absolute pad naar uw Serendipity-installatie');
@define('INSTALL_UPLOADPATH', 'Uploadpad');
@define('INSTALL_UPLOADPATH_DESC', 'Alle uploads worden in deze map geplaatst, relatief ten opzichte van het \'Volledige pad\' - meestal is dit \'uploads/\'');
@define('INSTALL_RELPATH', 'Browserpad');
@define('INSTALL_RELPATH_DESC', 'Het pad naar Serendipity voor gebruik in uw browser, meestal is dit \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Browserpad templates');
@define('INSTALL_RELTEMPLPATH_DESC', 'Het pad naar de templates - gerelateerd aan het \'Browserpad\'');
@define('INSTALL_RELUPLOADPATH', 'Browserpad uploads');
@define('INSTALL_RELUPLOADPATH_DESC', 'Het pad naar uw uploadmap - gerelateerd aan het \'Browserpad\'');
@define('INSTALL_URL', 'URL naar uw weblog');
@define('INSTALL_URL_DESC', 'De URL naar uw Serendipity-installatie');
@define('INSTALL_INDEXFILE', 'Indexbestand');
@define('INSTALL_INDEXFILE_DESC', 'De naam van uw Serendipity-indexbestand');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Algemene Instellingen');
@define('INSTALL_CAT_SETTINGS_DESC', 'Pas aan hoe Serendipity zich gedraagt');
@define('INSTALL_USERNAME', 'Gebruikersnaam beheerder');
@define('INSTALL_USERNAME_DESC', 'De gebruikersnaam van de beheerder');
@define('INSTALL_PASSWORD', 'Wachtwoord beheerder');
@define('INSTALL_PASSWORD_DESC', 'Het wachtwoord van de beheerder');
@define('INSTALL_EMAIL', 'E-mailadres van beheerder');
@define('INSTALL_EMAIL_DESC', 'E-mailadres van de beheerder van het weblog');
@define('INSTALL_SENDMAIL', 'E-mails versturen naar beheerder?');
@define('INSTALL_SENDMAIL_DESC', 'Wilt u een e-mail ontvangen wanneer er een reactie geplaatst is op een van uw artikelen?');
@define('INSTALL_SUBSCRIBE', 'Abonneren op artikelen?');
@define('INSTALL_SUBSCRIBE_DESC', 'Maak het mogelijk voor gebruikers om zich te abonneren op uw artikelen en zo een e-mail te ontvangen wanneer er nieuwe reacties op worden geplaatst');
@define('INSTALL_BLOGNAME', 'Weblognaam');
@define('INSTALL_BLOGNAME_DESC', 'De naam van uw weblog');
@define('INSTALL_BLOGDESC', 'Weblogomschrijving');
@define('INSTALL_BLOGDESC_DESC', 'De omschrijving van het weblog');
@define('INSTALL_LANG', 'Taal');
@define('INSTALL_LANG_DESC', 'Selecteer de taal die gebruikt wordt voor uw weblog');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Uiterlijk en opties');
@define('INSTALL_CAT_DISPLAY_DESC', 'Bepaal het gedrag en uiterlijk van Serendipity');
@define('INSTALL_WYSIWYG', 'WYSIWYG-editor gebruiken?');
@define('INSTALL_WYSIWYG_DESC', 'Wilt u de WYSIWYG editor gebruiken? (Werkt met IE5+ en gedeeltelijk met Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forceer XHTML 1.1-compatibiliteit');
@define('INSTALL_XHTML11_DESC', 'Wilt u XHTML 1.1-compatibiliteit forceren? (Dit kan problemen veroorzaken voor oudere browsers)');
@define('INSTALL_POPUP', 'Gebruikmaken van pop-ups');
@define('INSTALL_POPUP_DESC', 'Wilt u gebruikmaken van pop-ups voor reacties, trackbacks e.d.?');
@define('INSTALL_EMBED', 'Is Serendipity geïntegreerd in een andere pagina?');
@define('INSTALL_EMBED_DESC', 'Als u Serendipity wilt integreren in een bestaande pagina, zet deze optie dan op ja om de headers weg laten en gewoon de inhoud weer te geven. Met behulp van de indexbestandoptie kunt u een wikkelklasse gebruiken waarin u de normale webpagina-headers kunt zetten. Bekijk het README-bestand voor meer informatie!');
@define('INSTALL_TOP_AS_LINKS', 'Top Uitgaande Hyperlinks/-verwijzers weergeven als hyperlinks?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"nee": Uitgaande Hyperlinks en Verwijzers worden als gewone tekst weergeven om het spammen door zoekmachines te voorkomen. "ja": Uitgaande Hyperlinks en Verwijzers worden getoond als hyperlinks. "standaard": Gebruik de instellingen vanuit uw algemene instellingen (aanbevolen).');
@define('INSTALL_BLOCKREF', 'Geblokkeerde Verwijzers');
@define('INSTALL_BLOCKREF_DESC', 'Zijn er speciale hosts waarvan u niet wilt dat zij in uw Topverwijzerslijst komen te staan? Scheid de hosts met \';\'');
@define('INSTALL_REWRITE', 'URL Herschrijven');
@define('INSTALL_REWRITE_DESC', 'De regels die gehanteerd worden bij het genereren van URLs. Het inschakelen van deze optie zorgt voor aantrekkelijke URLs, het maakt het makkelijker voor zoekmachines om uw weblog te indexeren. De webserver moet wel mod_rewrite of "AllowOverride All" toestaan in uw Serendipity-map. Standaard staat deze optie op automatisch');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Afbeeldingsinstellingen');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Hier kunt u aangeven hoe Serendipity met afbeeldingen moet omgaan');
@define('INSTALL_IMAGEMAGICK', 'Gebruik Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Heeft u Imagemagick geïnstalleerd en wilt u het gebruiken om het formaat van de afbeeldingen aan te passen?');
@define('INSTALL_IMAGEMAGICKPATH', 'Pad naar het conversieprogramma');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Volledig pad en naam van uw Imagemagick-programma convert');
@define('INSTALL_THUMBSUFFIX', 'Achtervoegsel miniaturen');
@define('INSTALL_THUMBSUFFIX_DESC', 'Miniaturen krijgen een naam volgens het formaat: origineel.[achtervoegsel].ext');
@define('INSTALL_THUMBWIDTH', 'Formaat miniaturen');
@define('INSTALL_THUMBWIDTH_DESC', 'Maximale breedte van automatisch aangemaakte miniaturen');
@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
@define('INSTALL_THUMBDIM_WIDTH', 'Width');
@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" only limit the chosen dimension, so the other could be larger than the max size.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Uw persoonlijke gegevens');
@define('USERCONF_CAT_PERSONAL_DESC', 'Pas uw persoonlijke gegevens aan');
@define('USERCONF_USERNAME', 'Uw gebruikersnaam');
@define('USERCONF_USERNAME_DESC', 'De gebruikersnaam waarmee in zich aanmeldt op het weblog');
@define('USERCONF_PASSWORD', 'Uw wachtwoord');
@define('USERCONF_PASSWORD_DESC', 'Het wachtwoord waarmee u zich wilt aanmelden op het weblog');
@define('USERCONF_EMAIL', 'Uw e-mailadres');
@define('USERCONF_EMAIL_DESC', 'Uw eigen e-mailadres');
@define('USERCONF_SENDCOMMENTS', 'Bericht bij reacties?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Wilt u een e-mail ontvangen wanneer er reacties geplaatst worden op uw artikelen?');
@define('USERCONF_SENDTRACKBACKS', 'Bericht bij trackbacks?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Wilt u een e-mail ontvangen wanneer er een trackback naar een van uw artikelen is gemaakt?');
@define('USERCONF_ALLOWPUBLISH', 'Toestaan berichten te plaatsen?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Mag deze gebruiker artikelen publiceren?');
@define('SUCCESS', 'Succes');
@define('POWERED_BY_SHOW_TEXT', 'Toon "Serendipity" als tekst');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Dit laat "Serendipity Weblog" als tekst zien');
@define('POWERED_BY_SHOW_IMAGE', 'Toon "Serendipity" met logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Toont het Serendipity-logo');
@define('PLUGIN_ITEM_DISPLAY', 'Waar moeten de items worden weergegeven?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Alleen bij uitgebreide artikelen');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Alleen bij overzichtspagina');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Altijd');
@define('RSS_IMPORT_CATEGORY', 'Gebruik deze categorie voor artikelen met een onbekende categorie');

@define('COMMENTS_WILL_BE_MODERATED', 'Ingestuurde reacties zullen eerst worden gecontroleerd voor deze geplaatst worden.');
@define('YOU_HAVE_THESE_OPTIONS', 'U heeft de volgende opties tot uw beschikking:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Waarschuwing: Deze reactie moet eerst worden goedgekeurd voor deze wordt weergegeven');
@define('DELETE_COMMENT', 'Verwijder reactie');
@define('APPROVE_COMMENT', 'Keur reactie goed');
@define('REQUIRES_REVIEW', 'Moet nagekeken worden');
@define('COMMENT_APPROVED', 'Reactie #%s is goedgekeurd');
@define('COMMENT_DELETED', 'Reactie #%s is succesvol verwijderd');
@define('COMMENTS_MODERATE', 'Reacties & trackbacks moeten worden gecontroleerd');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Waarschuwing: Deze trackback moet worden goedgekeurd voor hij wordt weergegeven');
@define('DELETE_TRACKBACK', 'Verwijder trackback');
@define('APPROVE_TRACKBACK', 'Keur trackback goed');
@define('TRACKBACK_APPROVED', 'Trackback #%s is goedgekeurd');
@define('TRACKBACK_DELETED', 'Trackback #%s is verwijderd');
@define('VIEW', 'Bekijk');
@define('COMMENT_ALREADY_APPROVED', 'Reactie #%s is reeds goedgekeurd');
@define('COMMENT_EDITED', 'De reactie is aangepast');
@define('HIDE', 'Verbergen');
@define('VIEW_EXTENDED_ENTRY', 'Ga door met lezen van "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'De link is niet bedoeld om aangeklikt te worden. Het bevat een trackback-URL voor dit artikel. U kunt deze URL gebruiken om ping- & trackbacks te versturen van uw weblog naar dit artikel. Om deze URL te kopiëren klikt u met de rechtermuisknop en kiest u voor "Koppelingslocatie kopiëren.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Gebruik https om aan te melden');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Laat de aanmelding via https verlopen. Uw webserver moet dit echter wel ondersteunen!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Externe links aanklikbaar maken?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nee": Ongecontroleerde externe hyperlinks (Top Uitgaande Hyperlinks, Topverwijzers, reacties) worden niet getoond of getoond als gewone tekst om spam vanuit zoekmachines te voorkomen. (aanbevolen). "ja": Ongecontroleerde externe hyperlinks worden gewoon getoond als hyperlinks. De Zijbalkpluginconfiguratie kan dit opheffen!');
@define('PAGE_BROWSE_COMMENTS', 'Pagina %s van %s, in totaal %s reactie(s)');
@define('FILTERS', 'Filters');
@define('FIND_ENTRIES', 'Zoek artikelen');
@define('FIND_COMMENTS', 'Zoek reacties');
@define('FIND_MEDIA', 'Zoek media');
@define('FILTER_DIRECTORY', 'Map');
@define('SORT_BY', 'Sorteren op');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Er is geen trackback verzonden: Kan geen verbinding maken met %s via poort %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Mediabibliotheek');
@define('ADD_MEDIA', 'Voeg media toe');
@define('ENTER_MEDIA_URL', 'Voer de URL van een op te halen bestand in:');
@define('ENTER_MEDIA_UPLOAD', 'Selecteer een bestand dat u wilt uploaden:');
@define('SAVE_FILE_AS', 'Sla bestand op als:');
@define('STORE_IN_DIRECTORY', 'Sla op in de volgende map: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Voeg een bestand toe aan uw mediaverzameling:</b><p>Hier kunt u mediabestanden uploaden, of aangeven waar ze zich op het Internet bevinden. Als u geen goede afbeelding kunt vinden, kunt u <a href="http://images.google.com" target="_blank">zoeken naar afbeeldingen met Google</a>. Bedenk wel dat de meeste afbeeldingen auteursrechtelijk beschermd zijn en u dus toestemming moet vragen om ze te mogen gebruiken.</p><p><b>Selectiemethode:</b></p><br/>');
@define('MEDIA_RENAME', 'Hernoem dit bestand');
@define('IMAGE_RESIZE', 'Wijzig formaat van de afbeelding');
@define('MEDIA_DELETE', 'Verwijder dit bestand');
@define('FILES_PER_PAGE', 'Bestanden per pagina');
@define('CLICK_FILE_TO_INSERT', 'Selecteer het bestand dat u wilt invoegen:');
@define('SELECT_FILE', 'Selecteer bestand om in te voegen');
@define('MEDIA_FULLSIZE', 'Volledige grootte');
@define('CALENDAR_BOW_DESC', 'De eerste dag van de week. Standaard is maandag');
@define('SUPERUSER', 'Weblogbeheer');
@define('ALLOWS_YOU_BLAHBLAH', 'Toont een hyperlink naar de beheersectie van uw weblog');
@define('CALENDAR', 'Kalender');
@define('SUPERUSER_OPEN_ADMIN', 'Open beheerscherm');
@define('SUPERUSER_OPEN_LOGIN', 'Open aanmeldscherm');
@define('INVERT_SELECTIONS', 'Keer selectie om');
@define('COMMENTS_DELETE_CONFIRM', 'Weet u zeker dat u de geselecteerde reacties wilt verwijderen?');
@define('COMMENT_DELETE_CONFIRM', 'Weet u zeker dat u de reactie #%d, geschreven door %s, wilt verwijderen?');
@define('DELETE_SELECTED_COMMENTS', 'Verwijder geselecteerde reacties');
@define('VIEW_COMMENT', 'Bekijk reactie');
@define('VIEW_ENTRY', 'Bekijk artikel');
@define('DELETE_FILE_FAIL' , 'Kan bestand <b>%s</b> niet verwijderen');
@define('DELETE_THUMBNAIL', 'Verwijder miniatuur <b>%s</b>');
@define('DELETE_FILE', 'Verwijder bestand genaamd <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'U staat op het punt om bestand <b>%s</b></p><br/> te verwijderen. Als u dit bestand in een van uw artikelen gebruikt, zal dit leiden tot niet werkende hyperlinks of vermiste afbeeldingen.<br />Weet u zeker dat u door wilt gaan?<br /><br />');
@define('TRACKBACK_SENDING', 'Trackback aan het versturen naar %s...');
@define('TRACKBACK_SENT', 'Trackback succesvol');
@define('TRACKBACK_FAILED', 'Trackback functioneert niet: %s');
@define('TRACKBACK_NOT_FOUND', 'Er is geen trackback-URI gevonden.');
@define('TRACKBACK_URI_MISMATCH', 'De automatisch gedetecteerde trackback-URI komt niet overeen met de URI die u heeft opgegeven.');
@define('TRACKBACK_CHECKING', '<u>%s</u> op mogelijke trackbacks aan het controleren...');
@define('TRACKBACK_NO_DATA', 'Doel bevatte geen gegevens');
@define('TRACKBACK_SIZE', 'Doel-URI heeft de maximale grootte van %s bytes overschreden.');
@define('COMMENTS_VIEWMODE_THREADED', 'Samengevoegd');
@define('COMMENTS_VIEWMODE_LINEAR', 'Lineair');
@define('DISPLAY_COMMENTS_AS', 'Geeft reacties weer als');
@define('COMMENTS_FILTER_SHOW', 'Tonen');
@define('COMMENTS_FILTER_ALL', 'Alles');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Alleen goedgekeurden');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Wachtend op goedkeuring');
@define('RSS_IMPORT_BODYONLY', 'Voeg alle geïmporteerde teksten in de "Artikeltekst"-sectie en splits deze niet op naar de "Uitgebreide tekst"-sectie.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Geef volledige artikelen weer in de verzamelpublicatie');
@define('WEEK', 'Week');
@define('WEEKS', 'Weken');
@define('MONTHS', 'Maanden');
@define('DAYS', 'Dagen');
@define('ARCHIVE_FREQUENCY', 'Kalenderitemfrequentie');
@define('ARCHIVE_FREQUENCY_DESC', 'Het interval waarin artikelen gegroepeerd worden');
@define('ARCHIVE_COUNT', 'Aantal items in de lijst');
@define('ARCHIVE_COUNT_DESC', 'Het totaal aantal intervallen dat weergegeven moet worden');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Hieronder staat een lijst met geïnstalleerde plugins');
@define('SIDEBAR_PLUGIN', 'zijbalkplugin');
@define('EVENT_PLUGIN', 'evenementenplugin');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klik hier om een nieuwe %s te installeren');
@define('VERSION', 'versie');
@define('INSTALL', 'Installeren');
@define('ALREADY_INSTALLED', 'Reeds geïnstalleerd');
@define('SELECT_A_PLUGIN_TO_ADD', 'Selecteer welke plugin u wenst te installeren');
@define('INSTALL_OFFSET', 'Verschil met servertijd');
@define('STICKY_POSTINGS', 'Klevend');
@define('INSTALL_FETCHLIMIT', 'Artikelen die weergegeven moeten worden');
@define('INSTALL_FETCHLIMIT_DESC', 'Aantal artikelen die weergeven moeten worden per pagina');
@define('IMPORT_ENTRIES', 'Importeer artikelen');
@define('EXPORT_ENTRIES', 'Exporteer artikelen');
@define('IMPORT_WELCOME', 'Welkom bij de Serendipity-importeerassistent');
@define('IMPORT_WHAT_CAN', 'Hiermee kunt u artikelen uit andere weblog software importeren');
@define('IMPORT_SELECT', 'Selecteer uit welk type weblog u de gegevens wilt importeren');
@define('IMPORT_PLEASE_ENTER', 'Voer hieronder de nodige gegevens in');
@define('IMPORT_NOW', 'Importeer nu!');
@define('IMPORT_STARTING', 'Starten met importeren...');
@define('IMPORT_FAILED', 'Importeren niet gelukt');
@define('IMPORT_DONE', 'Importeren succesvol uitgevoerd');
@define('IMPORT_WEBLOG_APP', 'Weblogapplicatie');
@define('EXPORT_FEED', 'Exporteer volledige verzamelpublicatie');
@define('STATUS', 'Status na importeren');
@define('IMPORT_GENERIC_RSS', 'Generische RSS-import');
@define('ACTIVATE_AUTODISCOVERY', 'Verstuur trackbacks naar hyperlinks gevonden in dit artikel');
@define('WELCOME_TO_ADMIN', 'Welkom bij Serendipity Beheer.');
@define('PLEASE_ENTER_CREDENTIALS', 'Voer hieronder uw gegevens in.');
@define('ADMIN_FOOTER_POWERED_BY', 'Aangedreven door Serendipity %s en PHP %s');
@define('INSTALL_USEGZIP', 'Maak gebruik van gzip-gecomprimeerde pagina\'s');
@define('INSTALL_USEGZIP_DESC', 'Om de verzending van pagina\'s te versnellen, kunnen de pagina\'s gecomprimeerd worden. Dit is alleen mogelijk als de browser dit ondersteund. Het wordt aangeraden');
@define('INSTALL_SHOWFUTURE', 'Toon toekomstige artikelen');
@define('INSTALL_SHOWFUTURE_DESC', 'Als dit is ingeschakeld worden alle artikelen met een publicatiedatum in de toekomst weergeven. Standaard worden alleen artikelen weergegeven waarvan de publicatiedatum al bereikt werd.');
@define('INSTALL_DBPERSISTENT', 'Gebruik altijd openstaande verbindingen');
@define('INSTALL_DBPERSISTENT_DESC', 'Laat de verbinding met uw databank openstaan. Lees meer hierover op de (<a href="http://php.net/manual/features.persistent-connections.php" target="_blank">PHP-website</a>). Dit wordt niet aangeraden');
@define('NO_IMAGES_FOUND', 'Geen afbeeldingen gevonden');
@define('PERSONAL_SETTINGS', 'Persoonlijke instellingen');
@define('REFERER', 'Verwijzer');
@define('NOT_FOUND', 'Niet gevonden');
@define('WRITABLE', 'Beschrijfbaar');
@define('NOT_WRITABLE', 'Niet beschrijfbaar');
@define('PROBLEM_DIAGNOSTIC', 'Door een ernstig probleem kunt u niet doorgaan met de installatie totdat u de bovenstaande fouten gecorrigeerd heeft');
@define('SELECT_INSTALLATION_TYPE', 'Selecteer welk installatietype u wenst');
@define('WELCOME_TO_INSTALLATION', 'Welkom bij de Serendipity-installatie');
@define('FIRST_WE_TAKE_A_LOOK', 'Eerst bekijken we uw huidige instellingen en zullen zo compatibiliteitsproblemen opsporen');
@define('ERRORS_ARE_DISPLAYED_IN', 'Alle fouten worden weergeven in %s, aanbevelingen in %s en voltooide taken in %s');
@define('RED', 'rood');
@define('YELLOW', 'geel');
@define('GREEN', 'groen');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s pre-installatiebericht');
@define('RECOMMENDED', 'Aanbevolen');
@define('ACTUAL', 'Huidig');
@define('PHPINI_CONFIGURATION', 'php.ini-configuratie');
@define('PHP_INSTALLATION', 'PHP-installatie');
@define('THEY_DO', 'positief');
@define('THEY_DONT', 'negatief');
@define('SIMPLE_INSTALLATION', 'Eenvoudige installatie');
@define('EXPERT_INSTALLATION', 'Geavanceerde installatie');
@define('COMPLETE_INSTALLATION', 'Complete installatie');
@define('WONT_INSTALL_DB_AGAIN', 'zal de databank niet opnieuw installeren');
@define('CHECK_DATABASE_EXISTS', 'Controleer de databank op aanwezigheid van de nodige tabellen');
@define('CREATING_PRIMARY_AUTHOR', 'Hoofdauteur \'%s\' aan het aanmaken');
@define('SETTING_DEFAULT_TEMPLATE', 'Standaardtemplate aan het instellen');
@define('INSTALLING_DEFAULT_PLUGINS', 'Standaardplugins aan het installeren');
@define('SERENDIPITY_INSTALLED', 'Serendipity is met succes geïnstalleerd');
@define('VISIT_BLOG_HERE', 'Bezoek uw weblog hier');
@define('THANK_YOU_FOR_CHOOSING', 'Dank u voor het gebruiken van Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Een fout is aangetroffen in de installatie');
@define('OPERATING_SYSTEM', 'Besturingssysteem');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' is ingesteld als uw huidige template');
@define('SEARCH_ERROR', 'De zoekfunctie werkte niet naar verwachting. Waarschuwing voor de beheerder van dit weblog: dit komt mogelijk door het ontbreken van indexsleutels in de databank. Op MySQL-systemen moet uw databankgebruikersaccount deze bewerking kunnen uitvoeren: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> De foutmelding van de databank is: <pre>%s</pre>');
@define('CATEGORY_REMAINING', ' Verwijder deze categorie en verplaatst de artikelen naar de volgende categorie ');
@define('CATEGORY_INDEX', 'Dit is een lijst met categorieën beschikbaar voor uw artikelen');
@define('NO_CATEGORIES', 'Geen categorieën');
@define('RESET_DATE', 'Datum terugstellen');
@define('RESET_DATE_DESC', 'Klik hier om de datum en tijd terug te stellen naar de huidige datum en tijd');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Toegangsrechten kunnen gezet worden met het volgende commando: `<em>%s</em>` op de mislukte map, of via een FTP-programma');
@define('WARNING_TEMPLATE_DEPRECATED', 'Waarschuwing: Uw huidige template gebruikt een oude templatemethode. U wordt aangeraden om dit indien mogelijk bij te werken.');
@define('ENTRY_PUBLISHED_FUTURE', 'Dit artikel is nog niet gepubliceerd');
@define('ENTRIES_BY', 'Artikelen van %s');
@define('PREVIOUS', 'Vorige');
@define('NEXT', 'Volgende');
@define('APPROVE', 'Goedkeuren');
@define('DO_MARKUP_DESCRIPTION', 'Voer tekstopmaak uit (smilies, verkort opmaak via *, /, _, ...). Met het uitschakelen van deze optie behoudt u de HTML-code in de tekst.');
@define('CATEGORY_ALREADY_EXIST', 'Een categorie met de naam "%s" bestaat al');
@define('IMPORT_NOTES', 'Opmerking:');
@define('ERROR_FILE_FORBIDDEN', 'U bent niet toegestaan om bestanden met actieve inhoud te uploaden');
@define('ADMIN', 'Beheerder');
@define('ADMIN_FRONTPAGE', 'Voorpagina');
@define('QUOTE', 'Citaat');
@define('IFRAME_SAVE', 'Serendipity slaat nu uw artikel op, maakt trackbacks aan en voert mogelijke XML-RPC-aanroepen uit. Dit kan even duren..');
@define('IFRAME_SAVE_DRAFT', 'Een conceptversie van dit artikel wordt bewaard');
@define('IFRAME_PREVIEW', 'Serendipity maakt nu een voorvertoning van uw artikel aan...');
@define('IFRAME_WARNING', 'Uw browser ondersteunt geen iframes. Open het bestand serendipity_config.inc.php en wijzig de variabele $serendipity[\'use_iframe\'] naar FALSE.');
@define('NONE', 'geen');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Standaardinstellingen voor nieuwe artikelen');
@define('UPGRADE', 'Bijwerken');
@define('UPGRADE_TO_VERSION', 'Bijwerken naar versie %s');
@define('DELETE_DIRECTORY', 'Verwijder map');
@define('DELETE_DIRECTORY_DESC', 'U staat op het punt om een map te verwijderen met mediabestanden die mogelijk gebruikt worden in uw artikelen.');
@define('FORCE_DELETE', ' Verwijder ALLE bestanden in deze map, inclusief diegenen die niet bekend zijn bij Serendipity');
@define('CREATE_DIRECTORY', 'Maak map');
@define('CREATE_NEW_DIRECTORY', 'Maak nieuwe map');
@define('CREATE_DIRECTORY_DESC', 'Hier kun je een nieuwe map aanmaken om mediabestanden in te plaatsen. Bedenk een naam voor de nieuwe map en kies een optionele bovenliggende map waarin deze geplaatst moet worden.');
@define('BASE_DIRECTORY', 'Basismap');
@define('USERLEVEL_EDITOR_DESC', 'Standaardredacteur');
@define('USERLEVEL_CHIEF_DESC', 'Hoofdredacteur');
@define('USERLEVEL_ADMIN_DESC', 'Beheerder');
@define('USERCONF_USERLEVEL', 'Toegangsniveau');
@define('USERCONF_USERLEVEL_DESC', 'Dit niveau wordt gebruikt om te bepalen wat voor soort rechten de gebruiker heeft tot het weblog');
@define('USER_SELF_INFO', 'Aangemeld als %s (%s)');
@define('ADMIN_ENTRIES', 'Artikelen');
@define('RECHECK_INSTALLATION', 'Installatie opnieuw controleren');
@define('IMAGICK_EXEC_ERROR', 'Niet uit te voeren: "%s", fout: %s, foutcode : %d');
@define('INSTALL_OFFSET_DESC', 'Vul het aantal uren in tussen de tijd van uw webserver (huidig: %clock%) en uw gewenste tijdzone');
@define('UNMET_REQUIREMENTS', 'Server voldoet niet aan de eisen: %s');
@define('CHARSET', 'Tekenset');
@define('AUTOLANG', 'Laat de bezoeker de taal bepalen');
@define('AUTOLANG_DESC', 'Als dit aan staat, zal de browserinstelling van de bezoeker de taal bepalen van uw artikelen en interface.');
@define('INSTALL_AUTODETECT_URL', 'Automatisch detecteren van HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Als dit aan staat, dan zal Serendipity er voor zorgen dat de HTTP-Host die werd gebruikt door uw bezoeker gezet zal worden als uw basis-URL. Hierdoor wordt het mogelijk zijn om meerdere domeinnamen te gebruiken voor uw weblog en het domein gebruiken voor alle hyperlinks in uw weblog binnen die sessie.');
@define('CONVERT_HTMLENTITIES', 'Proberen de HTML-entiteiten automatisch om te zetten?');
@define('EMPTY_SETTING', 'U heeft geen geldige waarde opgegeven voor "%s"!');
@define('USERCONF_REALNAME', 'Echte naam');
@define('USERCONF_REALNAME_DESC', 'Volledige naam van de auteur. Dit is de naam die wordt gezien door de lezers');
@define('HOTLINK_DONE', 'Bestand is gehotlinkt.<br />Klaar.');
@define('ENTER_MEDIA_URL_METHOD', 'Ophaalmethode:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Let op: Als u er voor kiest een hotlink te maken naar een andere website, zorg er voor dat u daarvoor toestemming heeft. Een hotlink maakt het mogelijk dat u illustraties buiten uw website kunt gebruiken, zonder deze lokaal op te slaan.');
@define('MEDIA_HOTLINKED', 'gehotlinkt');
@define('FETCH_METHOD_IMAGE', 'Download illustratie naar uw server');
@define('FETCH_METHOD_HOTLINK', 'Hotlink naar server');
@define('DELETE_HOTLINK_FILE', 'Verwijder het gehotlinkte bestand met de naam <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'E-mailadres laten zien?');
@define('IMAGE_MORE_INPUT', 'Meer afbeeldingen toevoegen');
@define('BACKEND_TITLE', 'Extra informatie in pluginconfiguratiescherm');
@define('BACKEND_TITLE_FOR_NUGGET', 'Hier kunt u een aangepaste tekst definiëren die zal worden weergegeven in het pluginconfiguratiescherm samen met de beschrijving van het HTML-blokje. Als u meerdere HTML-blokjes heeft met een lege titel, dan helpt dit om ze van elkaar te onderscheiden.');
@define('CATEGORIES_ALLOW_SELECT', 'Bezoekers toestaan om meerdere categorieën tegelijkertijd weer te geven?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Als dit is geactiveerd, dan zal er een aanvinkhokje naast elke categorie geplaatst worden. Gebruikers kunnen deze hokjes aanvinken om zo de artikelen van hun keuze te zien.');
@define('PAGE_BROWSE_PLUGINS', 'Pagina %s van %s, totaal %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Permanente hyperlinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Bepaalt diverse URL-patronen om permanente hyperlinks in uw weblog vast te leggen. U wordt geadviseerd op de standaardwaarden te gebruiken. Anders moet u proberen gebruik te maken van de %id%-waarde waar mogelijk, om te voorkomen dat Serendipity in de databank zoekt naar een doel-URL.');
@define('INSTALL_PERMALINK', 'Permanente hyperlink Artikel URL-structuur');
@define('INSTALL_PERMALINK_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot waar artikelen beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %title%, %day%, %month%, %year% en andere karakters.');
@define('INSTALL_PERMALINK_AUTHOR', 'Permanente hyperlink Auteur URL-structuur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot artikelen van bepaalde auteurs beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %realname%, %username%, %email% en andere karakters.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permanente hyperlink Categorie URL-structuur');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot de artikelen van bepaalde categorieën beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %name%, %parentname%, %description% en andere karakters.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permanente hyperlink Verzamelpublicatie Categorie URL-structuur');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot waar de verzamelpublicaties van bepaalde categorieën vrijkomen. U kunt gebruikmaken van de variabelen %id%, %name%, %description% en andere karakters.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Pad naar archieven');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Pad naar archief');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Pad naar categorieën');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Pad naar stopzetten abonnement reacties');
@define('INSTALL_PERMALINK_DELETEPATH', 'Pad naar verwijderen reacties');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Pad naar goedkeuren reacties');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Pad naar verzamelpublicaties');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Pad naar enkele plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Pad naar admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Zoekpad');
@define('INSTALL_CAL', 'Kalendertype');
@define('INSTALL_CAL_DESC', 'Kies het gewenste kalendertype');
@define('REPLY', 'Beantwoorden');
@define('USERCONF_GROUPS', 'Groepslidmaatschap');
@define('USERCONF_GROUPS_DESC', 'Deze gebruiker is lid van de volgende groepen. Lid zijn van meerdere groepen is mogelijk.');
@define('MANAGE_GROUPS', 'Beheer groepen');
@define('DELETED_GROUP', 'Groep #%d %s is verwijderd.');
@define('CREATED_GROUP', 'Nieuwe groep %s is aangemaakt');
@define('MODIFIED_GROUP', 'De eigenschappen van groep %s zijn veranderd');
@define('GROUP', 'Groep');
@define('CREATE_NEW_GROUP', 'Creëer een nieuwe groep');
@define('DELETE_GROUP', 'U staat op het punt om groep #%d %s te verwijderen. Weet u zeker dat u deze groep wilt verwijderen?');
@define('USERLEVEL_OBSOLETE', 'OPMERKING: Het attribuut userlevel wordt alleen nog maar gebruikt om compatibiliteitsproblemen met plugins en autorisatie te voorkomen. Gebruikersprivileges worden nu afgehandeld door het groepslidmaatschap!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner-ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'Het ID van de toevoer die u wilt publiceren');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner-afbeelding');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Naam van de te tonen afbeelding (of laat deze leeg voor een teller), zoals deze te vinden is op feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner-titel');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Titel (indien ingevuld) die naast de afbeelding getoond wordt');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner-afbeeldingtekst');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Tekst (indien ingevuld) die naast de afbeelding getoond wordt');
@define('SEARCH_TOO_SHORT', 'Uw zoekopdracht dient uit meer dan 3 tekens te bestaan. Door het toevoegen van * aan woorden, zoals s9y*, kunt u ook naar kortere woorden zoeken.');
@define('INSTALL_DBPORT', 'Databankpoort');
@define('INSTALL_DBPORT_DESC', 'De poort waarop de databankserver draait');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Gebruikersinterface: Externe Diensten');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Gebruikersinterface: Functionaliteit');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Gebruikersinterface: Volledige Aanpassingen');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Gebruikersinterface: Uitzicht');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Gebruikersinterface: Gerelateerd Aan Artikelen');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Beheer: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Beheer: Gebruikersbeheer');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Beheer: Meta-informatie');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Beheer: Templates');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Beheer: Functionaliteit');
@define('PLUGIN_GROUP_IMAGES', 'Afbeeldingen');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Opmaak/Structuur');
@define('PLUGIN_GROUP_STATISTICS', 'Statistieken');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Toegang tot persoonlijke configuratie');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Gebruikersniveaus wijzigen');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Recht op het aanmaken van artikelen wijzigen');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Recht op het publiceren van artikelen wijzigen');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Toegang tot systeemconfiguratie');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Toegang tot weblogconfiguratie');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Artikelen beheren');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Artikelen van anderen beheren');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Artikelen importeren');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Categorieën beheren');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Categorieën van anderen beheren');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Categorieën verwijderen');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Gebruikers beheren');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Gebruikers verwijderen');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Gebruikersniveau veranderen');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Gebruikers in uw eigen groep(en) beheren');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Gebruikers die niet in uw groep(en) zitten beheren');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Nieuwe gebruikers aanmaken');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Groepen beheren');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Plugins beheren');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Plugins van andere gebruikers beheren');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Mediabestanden beheren');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Mappen beheren');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Nieuwe mediabestanden toevoegen');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Mediabestanden verwijderen');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Mediabestanden van anderen beheren');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Mediabestanden bekijken');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Mediabestanden synchroniseren');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Reacties beheren');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Templates beheren');
@define('INSTALL_BLOG_EMAIL', 'E-mailadres van het weblog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Dit is het e-mailadres dat wordt gebruikt als afzender in uitgaande e-mails. Zorg ervoor dat het herkend wordt door de mail server - veel mail servers verwerpen berichten van een afzender die ze niet kennen.');
@define('CATEGORIES_PARENT_BASE', 'Laat alleen categorieën zien onder...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Kies een categorie waarvan alleen de onderliggende categorieën getoond moeten worden.');
@define('CATEGORIES_HIDE_PARALLEL', 'Verberg categorieën die geen deel uitmaken van de categorieënboom');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Zet deze optie aan als u categorieën wilt verbergen die deel uitmaken van een andere categorieënboom. Dit is vooral nuttig voor een multiblog dat de "Eigenschappen/Templates van categorieën"-plugin gebruikt.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Mediabestanden van anderen bekijken');
@define('CHARSET_NATIVE', 'Taalafhankelijk');
@define('INSTALL_CHARSET', 'Tekensetselectie');
@define('INSTALL_CHARSET_DESC', 'Hier kunt u kiezen tussen UTF-8 en taalafhankelijke (ISO, EUC, ...) tekensets. Sommige talen hebben alleen een UTF-8-vertaling, dus kiezen voor "Taalafhankelijk" heeft dan geen effect. UTF-8 wordt aangeraden voor een nieuwe installatie. Verander deze instelling niet als u al artikelen gemaakt heeft met speciale tekens, dit kan leiden tot corrupte tekens. Lees meer hierover op http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Zet plugin-API-interface aan');
@define('CALENDAR_EXTEVENT_DESC', 'Als deze optie aan staat, kunnen plugins de kalender gebruiken om hun eigen gebeurtenissen te laten zien. Zet dit alleen aan als u plugins geïnstalleerd heeft die dit gebruiken, anders vermindert het gewoon de performantie.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'De XML-RPC API-interface naar Serendipity wordt niet meer meegeleverd vanwege veiligheidsproblemen en omdat maar weinig mensen het gebruikten. Om hier gebruik van te maken moet u de XML-RPC-plugin installeren. De URL voor uw programma\'s verandert NIET. Zodra de plugin geïnstalleerd is, kunt u de API terug gebruiken.');
@define('PERM_READ', 'Leesrechten');
@define('PERM_WRITE', 'Schrijfrechten');

@define('PERM_DENIED', 'Toegang geweigerd.');
@define('INSTALL_ACL', 'Leesrechten voor categorieën toepassen');
@define('INSTALL_ACL_DESC', 'Als dit aan staat, zijn de gebruikersrechten voor categorieën van kracht als ingelogde gebruikers uw weblog bekijken. In het andere geval is de autorisatie niet van toepassing en wordt uw weblog iets sneller. Dus als u geen aparte leesrechten voor meerdere gebruikers nodig heeft, laat u deze optie best uit.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Configuratiesyntaxis fout voor optie "%s". Heeft inhoud van het type "%s" nodig.');
@define('USERCONF_CHECK_PASSWORD', 'Oud wachtwoord');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Als u het wachtwoord wijzigt in het veld hierboven moet u het huidige wachtwoord in dit veld invoeren.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Het oude wachtwoord dat u heeft ingegeven klopt niet en u bent dus niet geautoriseerd om het wachtwoord te wijzigen. Uw instellingen worden niet bewaard.');
@define('ERROR_XSRF', 'Uw browser heeft geen geldig HTTP-Referrer-adres verstuurd. Dit kan veroorzaakt worden door een verkeerd geconfigureerde browser/proxy of door een aanval die tegen u is gericht. Uw actie werd geannuleerd.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Hier definieert u de relatieve URL-structuur vanaf de basis-URL tot waar de verzamelingspublicatieaanvoer van elke gebruiker staat. U kunt de variabelen %id%, %realname%, %username%, %email% en gewone tekens gebruiken.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permanente hyperlink Verzamelpublicatie Auteur URL-structuur');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Pad naar auteurs');
@define('AUTHORS', 'Auteurs');
@define('AUTHORS_ALLOW_SELECT', 'Bezoekers toelaten om meerdere auteurs tegelijk te bekijken?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Als deze optie aan staat, zal er een aanvinkhokje naast elke auteur staan in de zijbalk. Bezoekers kunnen dan zelf kiezen welke artikelen ze willen zien.');
@define('AUTHOR_PLUGIN_DESC', 'Toont een lijst van auteurs');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Smarty-templates aan zetten?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Als deze optie aan staat, zal de plugin de mogelijkheden van Smarty templates benutten om een categorielijst te laten zien. U kunt dan het uitzicht wijzigen met behulp van het bestand "plugin_categories.tpl". Dit heeft wel nadelige gevolgen voor de performantie, dus u laat deze optie best af staan als u geen aanpassingen wilt doen.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Aantal artikelen per categorie tonen?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Aantal artikelen naast de naam van de auteur tonen?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Deze optie toont tussen haakjes het aantal artikelen van de auteur naast zijn naam.');
@define('CUSTOM_ADMIN_INTERFACE', 'Aangepaste beheersinterface beschikbaar');

@define('COMMENT_NOT_ADDED', 'Uw reactie kon niet worden toegevoegd omdat reacties op dit artikel niet toegelaten zijn, u ongeldige data heeft ingevoerd of omdat uw reactie geblokkeerd werd door antispammaatregelen.');
@define('INSTALL_TRACKREF', 'Verwijzingen onthouden?');
@define('INSTALL_TRACKREF_DESC', 'Door het onthouden van verwijzingen kunt u zien welke websites naar uw artikelen verwijzen. Dit wordt dikwijls misbruikt voor spam, dus u kunt het best uit zetten als u er last van heeft.');
@define('CATEGORIES_HIDE_PARENT', 'De geselecteerde bovenliggende categorie verbergen?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Als u de lijst van categorieën beperkt tot een bepaalde hoofdcategorie, dan zal standaard die categorie in de lijst getoond worden. Zet deze optie af om de naam van deze categorie niet te tonen.');
@define('WARNING_NO_GROUPS_SELECTED', 'Waarschuwing: u heeft geen enkel groepslidmaatschap geselecteerd. Dit zou u uitloggen uit het groepsbeheer, dus werden uw groepslidmaatschappen niet gewijzigd.');
@define('INSTALL_RSSFETCHLIMIT', 'Artikelen per toevoer');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Aantal artikelen die getoond worden per pagina van de verzamelpublicatietoevoer.');
@define('INSTAL_DB_UTF8', 'DB-tekensetconversie aanzetten');
@define('INSTAL_DB_UTF8_DESC', 'Stuurt een MySQL-"SET NAMES"-query met de gewenste tekenset naar de databank. Wijzig deze optie als u rare tekens ziet in uw weblog.');
@define('ONTHEFLYSYNCH', 'Automatische mediasynchronisatie aan zetten');
@define('ONTHEFLYSYNCH_DESC', 'Als deze optie aan staat, zal Serendipity zelf de mediaverzameling met de bestanden op de server vergelijken en beide synchroniseren.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'De gebruikersnaam mag niet leeg gelaten worden.');
@define('FURTHER_LINKS', 'Bijkomende Informatie');
@define('FURTHER_LINKS_S9Y', 'Serendipity-homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity-documentatie');
@define('FURTHER_LINKS_S9Y_BLOG', 'Officieel weblog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Reactie verwijderd)');

@define('CURRENT_AUTHOR', 'Huidige auteur');

@define('WORD_NEW', 'Nieuw');
@define('SHOW_MEDIA_TOOLBAR', 'Toon werkbalk binnen mediaselectiepop-up?');
@define('MEDIA_KEYWORDS', 'Mediasleutelwoorden');
@define('MEDIA_KEYWORDS_DESC', 'Voer een lijst van woorden in, gescheiden door een ";" die u wilt gebruiken als voorgedefinieerde sleutelwoorden voor mediabestanden.');
@define('MEDIA_EXIF', 'Importeer EXIF/JPEG-afbeeldingsgegevens');
@define('MEDIA_EXIF_DESC', 'Als dit aan staat, worden bestaande EXIF/JPEG-gegevens van afbeeldingen ingelezen en opgeslagen in de databank om weer te geven in de mediaverzameling.');
@define('MEDIA_PROP', 'Media-eigenschappen');


@define('GO_ADD_PROPERTIES', 'Wijzig afbeeldingseigenschappen');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Auteursrecht');
@define('MEDIA_PROPERTY_COMMENT1', 'Korte beschrijving');
@define('MEDIA_PROPERTY_COMMENT2', 'Lange beschrijving');
@define('MEDIA_PROPERTY_TITLE', 'Titel');
@define('MEDIA_PROP_DESC', 'Geef een lijst met eigenschapsvelden, gescheiden door een ";", die u wilt definiëren voor elk mediabestand');
@define('MEDIA_PROP_MULTIDESC', '(U kunt ":MULTI" aan een item toevoegen om aan te geven dat het een lange tekst zal bevatten in plaats van slechts enkele tekens)');

@define('STYLE_OPTIONS_NONE', 'Deze template heeft geen specifieke opties. Als u wilt weten hoe u opties kunt definiëren voor uw sjabloon, lees dan in de technische documentatie op www.s9y.org het artikel "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Template-opties');

@define('PLUGIN_AVAILABLE_COUNT', 'Totaal: %d plugins.');

@define('SYNDICATION_RFC2616', 'Verzamelpublicatie moet aan RFC2616 voldoen');
@define('SYNDICATION_RFC2616_DESC', 'RFC2616 NIET afdwingen heeft tot gevolg dat na ontvangst van een Conditional GET Serendipity de artikelen teruggeeft die gewijzigd werden sinds de laatste opvraging. Als deze optie niet actief is, zullen bezoekers alle artikelen krijgen die gewijzigd zijn sinds hun laatste opvraging, wat als positief wordt ervaren. Maar sommige programma\'s, zoals Planet, kunnen zich dan vreemd gedragen omdat ze wel strikt werken volgens RFC2616. Dus als deze optie aan staat, zal je de RFC wel afdwingen, maar dan kunnen lezers van je verzamelpublicatietoevoer artikelen mislopen tijdens hun vakantie. Dus ofwel ondervinden verzamelprogramma\'s zoals Planet er last van, ofwel de mensen die je weblog lezen. Als u klachten krijgt van een van beide partijen kunt u deze optie omschakelen. Referentie: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Geassocieerde datum');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automatisch toegewezen nieuwe bestandsnaam: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. uploadgrootte bestand');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Geef de maximale bestandsgrootte in bytes bij uploaden. Deze instelling kan herroepen worden door serverinstellingen in php.ini: upload_max_filesize, post_max_size, max_input_time hebben allemaal voorrang op deze instelling. Als u dit leeg laat worden alleen de serverinstellingen gebruikt.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Fout: U kan geen bestanden uploaden die groter zijn dan %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. breedte van afbeeldingen bij uploaden');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Geef de maximale breedte van afbeeldingen in pixels bij uploaden.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. hoogte van afbeeldingen bij uploaden');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Geef de maximale hoogte van afbeeldingen in pixels bij uploaden.');
@define('MEDIA_UPLOAD_DIMERROR', 'Fout: U kan geen afbeeldingen uploaden die groter zijn dan %s x %s pixels!');

@define('MEDIA_TARGET', 'Doel voor deze hyperlink');
@define('MEDIA_TARGET_JS', 'Pop-upvenster (met JavaScript, adaptieve grootte)');
@define('MEDIA_ENTRY', 'Alleenstaand artikel');
@define('MEDIA_TARGET_BLANK', 'Pop-upvenster (met target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Dynamische verandering van afbeeldingsgrootte toelaten?');
@define('MEDIA_DYN_RESIZE_DESC', 'Als deze optie aan staat, kan de mediaselector afbeeldingen van willekeurige grootte teruggeven met behulp van een GET-variabele. De resultaten worden bijgehouden, wat veel opslagruimte kan gebruiken als het veel gebruikt wordt.');

@define('MEDIA_DIRECTORY_MOVED', 'Map en bestanden werden succesvol verplaatst naar %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Map en bestanden konden niet verplaatst worden naar "%s"!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'Op niet-MySQL-databanken is het niet mogelijk om door elk artikel te lopen om de URL van de map te vervangen. U moet manueel in al uw artikelen de URL aanpassen. U kunt de map nog terugplaatsen naar zijn oude locatie als u dit te omslachtig vindt.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'De URL van de verplaatste map werd aangepast in %s artikelen.');
@define('PLUGIN_ACTIVE', 'Actief');
@define('PLUGIN_INACTIVE', 'Inactief');
@define('PREFERENCE_USE_JS', 'Geavanceerde JavaScript-functie inschakelen?');
@define('PREFERENCE_USE_JS_DESC', 'Hiermee kunt u geavanceerde JavaScript-functies inschakelen voor verbeterd gebruiksgemak, zoals het herschikken van plugins in de pluginconfiguratiesectie door ze te verslepen.');

@define('PREFERENCE_USE_JS_WARNING', '(Deze pagina maakt gebruik van geavanceerde JavaScript-functies. Als u daardoor problemen ondervindt, schakelt u dit best uit in uw persoonlijke instellingen of schakelt u JavaScript uit in uw browser)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Pad naar reacties');
@define('PERM_SET_CHILD', 'Geef dezelfde toegangsrechten aan alle onderliggende mappen');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Verboden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Verboden evenementen');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Plugintoegangsrechten per groep aan zetten?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Als dit aan staat, kunt u per gebruikersgroep bepalen welke plugins/evenementen uitgevoerd mogen worden.');
@define('DELETE_SELECTED_ENTRIES', 'Geselecteerde artikelen verwijderen');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Toon alleen auteurs met minstens X artikelen');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Maak een bladwijzer van deze hyperlink en gebruik het dan bij elke website waarover je wilt schrijven om snel toegang te krijgen tot je weblog.');
@define('IMPORT_WP_PAGES', 'Ook bijlagen en statische pagina\'s als gewone artikelen ophalen?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
